@@ -19,22 +19,21 @@ class AWSSNSRegistration(object):
 
     @classmethod
     async def _register_service(cls, service: Any) -> None:
-        logging.getLogger('discovery.aws_sns_registration').info('Registering service "{}" [id: {}]'.format(service.name, service.uuid))
-        data = {
-            'name': service.name,
-            'uuid': service.uuid,
-            'http_endpoints': cls.http_endpoints.get(service)
-        }
-        await aws_sns_sqs_publish(service, data, topic='services-registration-register')
+        logging.getLogger("discovery.aws_sns_registration").info(
+            'Registering service "{}" [id: {}]'.format(service.name, service.uuid)
+        )
+        data = {"name": service.name, "uuid": service.uuid, "http_endpoints": cls.http_endpoints.get(service)}
+        await aws_sns_sqs_publish(service, data, topic="services-registration-register")
 
     @classmethod
     async def _deregister_service(cls, service: Any) -> None:
-        logging.getLogger('discovery.aws_sns_registration').info('Deregistering service "{}" [id: {}]'.format(service.name, service.uuid))
-        data = {
-            'name': service.name,
-            'uuid': service.uuid
-        }
+        logging.getLogger("discovery.aws_sns_registration").info(
+            'Deregistering service "{}" [id: {}]'.format(service.name, service.uuid)
+        )
+        data = {"name": service.name, "uuid": service.uuid}
         try:
-            await aws_sns_sqs_publish(service, data, topic='services-registration-deregister')
+            await aws_sns_sqs_publish(service, data, topic="services-registration-deregister")
         except Exception:
-            logging.getLogger('discovery.aws_sns_registration').info('Deregistering service "{}" failed [id: {}]'.format(service.name, service.uuid))
+            logging.getLogger("discovery.aws_sns_registration").info(
+                'Deregistering service "{}" failed [id: {}]'.format(service.name, service.uuid)
+            )
