@@ -14,12 +14,16 @@ class DummyRegistry(object):
 
     @classmethod
     async def _register_service(cls, service: Any) -> None:
-        logging.getLogger('discovery.dummy_registry').info('Registering service "{}" [id: {}]'.format(service.name, service.uuid))
+        logging.getLogger("discovery.dummy_registry").info(
+            'Registering service "{}" [id: {}]'.format(service.name, service.uuid)
+        )
         for host, port, method, pattern in cls.http_endpoints.get(service, []):
             pass
 
     @classmethod
     async def _deregister_service(cls, service: Any) -> None:
-        logging.getLogger('discovery.dummy_registry').info('Deregistering service "{}" [id: {}]'.format(service.name, service.uuid))
+        logging.getLogger("discovery.dummy_registry").info(
+            'Deregistering service "{}" [id: {}]'.format(service.name, service.uuid)
+        )
         for host, port, method, pattern in cls.http_endpoints.pop(service, []):
             pass
